'use strict';

var _testHelper = require('../testHelper');

describe('HandPicked', () => {
  const fullparseCode = [];
  fullparseCode.push((0, _testHelper.readFile)('fullObjects/simple'));
  fullparseCode.push((0, _testHelper.readFile)('fullObjects/spread'));
  fullparseCode.push((0, _testHelper.readFile)('fullObjects/media'));
  it('parseCode, doNothing', () => {
    fullparseCode.forEach(obj => {
      const generatedFromTree = (0, _testHelper.normalizeInput)(obj);
      expect(generatedFromTree).toBe((0, _testHelper.runLoader)(obj));
    });
  });

  it('temp', () => {
    const temp = {
      input: (0, _testHelper.readFile)('transforms/complexIn'),
      output: (0, _testHelper.readFile)('transforms/complexOut')
    };
    const generatedFromTree = (0, _testHelper.normalizeInput)(temp.output);
    expect(generatedFromTree).toBe((0, _testHelper.runLoader)(temp.input));
  });

  const transforms = [];
  transforms.push({
    input: (0, _testHelper.readFile)('transforms/simpleIn'),
    output: (0, _testHelper.readFile)('transforms/simpleOut')
  });
  transforms.push({
    input: (0, _testHelper.readFile)('transforms/spreadIn'),
    output: (0, _testHelper.readFile)('transforms/spreadOut')
  });
  transforms.push({
    input: (0, _testHelper.readFile)('transforms/complexIn'),
    output: (0, _testHelper.readFile)('transforms/complexOut')
  });
  transforms.push({
    input: (0, _testHelper.readFile)('transforms/realIn'),
    output: (0, _testHelper.readFile)('transforms/realOut')
  });

  it('transforms', () => {
    transforms.forEach(t => {
      const generatedFromTree = (0, _testHelper.normalizeInput)(t.output);
      expect(generatedFromTree).toBe((0, _testHelper.runLoader)(t.input));
    });
  });

  it('complexRealTransform', () => {
    const inp = (0, _testHelper.readFile)('transforms/complexRealIn');
    const out = (0, _testHelper.readFile)('transforms/complexRealOut');
    const generatedFromTree = (0, _testHelper.normalizeInput)(out);
    expect(generatedFromTree).toBe((0, _testHelper.runLoader)(inp));

    let inpES6 = (0, _testHelper.readFile)('transforms/complexRealInES6');
    let outES6 = (0, _testHelper.readFile)('transforms/complexRealOutES6');
    let generatedFromTreeES6 = (0, _testHelper.normalizeInput)(outES6);
    expect(generatedFromTreeES6).toBe((0, _testHelper.runLoader)(inpES6));

    inpES6 = (0, _testHelper.readFile)('transforms/complexFlowRealInES6');
    outES6 = (0, _testHelper.readFile)('transforms/complexFlowRealOutES6');
    generatedFromTreeES6 = (0, _testHelper.normalizeInput)(outES6);
    expect(generatedFromTreeES6).toBe((0, _testHelper.runLoader)(inpES6));
  });

  it('mediaQuery', () => {
    const inp = (0, _testHelper.readFile)('transforms/mediaQueryIn');
    const out = (0, _testHelper.readFile)('transforms/mediaQueryOut');
    const generatedFromTree = (0, _testHelper.normalizeInput)(out);
    expect(generatedFromTree).toBe((0, _testHelper.runLoader)(inp));
  });

  const simple = [];
  simple.push({
    input: (0, _testHelper.readFile)('simple/simpleIn'),
    output: (0, _testHelper.readFile)('simple/simpleOut')
  });
  simple.push({
    input: (0, _testHelper.readFile)('simple/simpleES6In'),
    output: (0, _testHelper.readFile)('simple/simpleES6Out')
  });
  simple.push({
    input: (0, _testHelper.readFile)('simple/simpleOverrideIn'),
    output: (0, _testHelper.readFile)('simple/simpleOverrideOut')
  });

  it('simple', () => {
    simple.forEach(t => {
      const generatedFromTree = (0, _testHelper.normalizeInput)(t.output);
      expect(generatedFromTree).toBe((0, _testHelper.runLoader)(t.input));
    });
  });

  it('webpack', () => {
    const inp = (0, _testHelper.readFile)('webpackIn');
    const out = (0, _testHelper.readFile)('webpackOut');
    const generatedFromTree = (0, _testHelper.normalizeInput)(out);
    expect(generatedFromTree).toBe((0, _testHelper.runLoader)(inp));
  });
});